#include <iostream>
#include <Producer/Version>

int main()
{
	std::cout << Producer::Version() << std::endl;
        return 0;
}
